==> usefuladbplus-0.10.tar.gz: usefuladbplus-0.10/setup.py <==
from setuptools import setup, find_packages
import codecs
import os
# 
here = os.path.abspath(os.path.dirname(__file__))
# 
with open(os.path.join(os.path.abspath(os.path.dirname(__file__)),'README.md'), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()\

from pathlib import Path
this_directory = Path(__file__).parent
#long_description = (this_directory / "README.md").read_text()

VERSION = '''0.10'''
DESCRIPTION = '''Automation library for ADB / Android'''

# Setting up
setup(
    name="usefuladbplus",
    version=VERSION,
    license='MIT',
    url = 'https://github.com/hansalemaos/usefuladbplus',
    author="Johannes Fischer",
    author_email="aulasparticularesdealemaosp@gmail.com",
    description=DESCRIPTION,
long_description = long_description,
long_description_content_type="text/markdown",
    #packages=['a_cv_imwrite_imread_plus', 'a_pandas_ex_apply_ignore_exceptions', 'adbeventparser', 'adbnativeblitz', 'flatten_everything', 'geteventplayback', 'istruthy', 'numexpr', 'numpy', 'opencv_python', 'pandas', 'touchtouch', 'usefuladb'],
    keywords=['adb', 'android', 'bots'],
    classifiers=['Development Status :: 4 - Beta', 'Programming Language :: Python :: 3 :: Only', 'Programming Language :: Python :: 3.10', 'Topic :: Software Development :: Libraries :: Python Modules', 'Topic :: Utilities'],
    install_requires=['a_cv_imwrite_imread_plus', 'a_pandas_ex_apply_ignore_exceptions', 'adbeventparser', 'adbnativeblitz', 'flatten_everything', 'geteventplayback', 'istruthy', 'numexpr', 'numpy', 'opencv_python', 'pandas', 'touchtouch', 'usefuladb'],
    include_package_data=True
)
#python setup.py sdist bdist_wheel
#twine upload dist/*

==> usefuladbplus-0.11.tar.gz: usefuladbplus-0.11/setup.py <==
from setuptools import setup, find_packages
import codecs
import os
# 
here = os.path.abspath(os.path.dirname(__file__))
# 
with open(os.path.join(os.path.abspath(os.path.dirname(__file__)),'README.md'), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()\

from pathlib import Path
this_directory = Path(__file__).parent
#long_description = (this_directory / "README.md").read_text()

VERSION = '''0.11'''
DESCRIPTION = '''Automation library for ADB / Android'''

# Setting up
setup(
    name="usefuladbplus",
    version=VERSION,
    license='MIT',
    url = 'https://github.com/hansalemaos/usefuladbplus',
    author="Johannes Fischer",
    author_email="aulasparticularesdealemaosp@gmail.com",
    description=DESCRIPTION,
long_description = long_description,
long_description_content_type="text/markdown",
    #packages=['a_cv_imwrite_imread_plus', 'a_pandas_ex_apply_ignore_exceptions', 'adbeventparser', 'adbnativeblitz', 'flatten_everything', 'geteventplayback', 'istruthy', 'numexpr', 'numpy', 'opencv_python', 'opencv_python_headless', 'pandas', 'touchtouch', 'usefuladb'],
    keywords=['adb', 'android', 'bots'],
    classifiers=['Development Status :: 4 - Beta', 'Programming Language :: Python :: 3 :: Only', 'Programming Language :: Python :: 3.10', 'Topic :: Software Development :: Libraries :: Python Modules', 'Topic :: Utilities'],
    install_requires=['a_cv_imwrite_imread_plus', 'a_pandas_ex_apply_ignore_exceptions', 'adbeventparser', 'adbnativeblitz', 'flatten_everything', 'geteventplayback', 'istruthy', 'numexpr', 'numpy', 'opencv_python', 'opencv_python_headless', 'pandas', 'touchtouch', 'usefuladb'],
    include_package_data=True
)
#python setup.py sdist bdist_wheel
#twine upload dist/*
